@@ -1,7 +1,7 @@
 # zcross/raw/binding.py
 # -*- coding: utf-8 -*-
 # PyXB bindings for NM:626ec537dfcf4e27e1a94ab21ad8ef1c6da8dfdf
-# Generated 2021-01-08 04:08:11.809567 by PyXB version 1.2.6 using Python 3.7.3.final.0
+# Generated 2021-04-04 00:54:17.011177 by PyXB version 1.2.6 using Python 3.7.3.final.0
 # Namespace https://zcross.net
 
 from __future__ import unicode_literals
@@ -14,7 +14,7 @@ import pyxb.utils.domutils
 import sys
 import pyxb.utils.six as _six
 # Unique identifier for bindings created at the same time
-_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:5c0417d0-5156-11eb-8c26-50eb711e81f1')
+_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:22e4ee52-94c7-11eb-9284-50eb711e81f1')
 
 # Version of PyXB used to generate the bindings
 _PyXBVersion = '1.2.6'
